/*
 * Copyright 2010 Andreas Schmidt Jensen
 *
 * This file is part of LEGO-Jason-NXT.
 *
 * LEGO-Jason-NXT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LEGO-Jason-NXT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LEGO-Jason-NXT.  If not, see <http://www.gnu.org/licenses/>.
 */
// Linefollower agent for the LEGO Mindstorms NXT
// Uses two sensors to detect whether it is on the line.
// The agent assumes that it is initially on a line (i.e. both sensors are showing bright light).
// It may therefore not work if not placed on a line 

/* Initial beliefs and rules */
// the sensors must be different, otherwise the light value from one sensor will be compared to it self
distinct_sensors(Sensor1, Sensor2) :- Sensor1 \== Sensor2.  
// the robot is on the line if both sensors are showing a bright value (currently set to greater than 350)
on_line(Value1, Value2) :- Value1 >= 350 & Value2 >= 350.
// the robot should turn if one value is dark and the other is bright (i.e. the line is turning)
turning(Value1, Value2) :- Value1 < 350 & Value2 >= 350.

/* Initial goals */
!move.

/* Plans */
// move forward if both sensors are sampling bright values
+!move 	: 	light(S1, V1) & light(S2, V2) & distinct_sensors(S1, S2) & on_line(V1, V2)
		<-  forward([a,b],[60,60]); !!move.

// turning
+!move 	:  	light(1, V1) & light(2, V2) & turning(V1,V2)
		<-	rotate([a,b],[-30,15]); !!move.
+!move 	:  	light(1, V1) & light(2, V2) & turning(V2,V1)
		<-	rotate([a,b],[15, -30]); !!move.
		
// if nothing has been perceived yet, wait, then reintroduce goal.
+!move  :	not light(_,_)
		<- .wait("+light(_,_)");
			!move.
			
// upon failure, start from scratch and reintroduce.
-!move <-	.drop_all_desires; .abolish(light(_,_)); !!move.